@@ -1,23 +1,46 @@
 package cPanel::TaskQueue::Scheduler;
 BEGIN {
-  $cPanel::TaskQueue::Scheduler::VERSION = '0.601';
+  $cPanel::TaskQueue::Scheduler::VERSION = '0.602';
 }
 
-# cpanel - cPanel/TaskQueue/Scheduler.pm          Copyright(c) 2010 cPanel, Inc.
+# cpanel - cPanel/TaskQueue/Scheduler.pm          Copyright(c) 2012 cPanel, Inc.
 #                                                           All rights Reserved.
 # copyright@cpanel.net                                         http://cpanel.net
 #
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions are met:
+#     * Redistributions of source code must retain the above copyright
+#       notice, this list of conditions and the following disclaimer.
+#     * Redistributions in binary form must reproduce the above copyright
+#       notice, this list of conditions and the following disclaimer in the
+#       documentation and/or other materials provided with the distribution.
+#     * Neither the name of the owner nor the names of its contributors may
+#       be used to endorse or promote products derived from this software
+#       without specific prior written permission.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
+# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+# DISCLAIMED. IN NO EVENT SHALL  BE LIABLE FOR ANY
+# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
+# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
 # This module handles queuing of tasks for execution. The queue is persistent
 # handles consolidating of duplicate tasks.
 
 use strict;
+
 #use warnings;
-use cPanel::TaskQueue      ();
+use cPanel::TaskQueue ();
 use cPanel::TaskQueue::Task();
-use cPanel::StateFile      ();
+use cPanel::StateFile ();
 
 # -----------------------------------------------------------------------------
-# Policy code: The following allows is a little weird because its intent is to 
+# Policy code: The following allows is a little weird because its intent is to
 # change the policy by which some code is executed, without adding a gratuitous
 # object and polymorphism into the mix.
 #
@@ -37,16 +60,16 @@ sub import {
     my $class = shift;
     die "Not an even number of arguments to the $pkg module\n" if @_ % 2;
     die "Policies already set elsewhere\n" if $are_policies_set;
-    return 1 unless @_; # Don't set the policies flag.
+    return 1 unless @_;    # Don't set the policies flag.
 
-    while ( @_ ) {
-        my ($policy,$module) = splice( @_, 0, 2 );
+    while (@_) {
+        my ( $policy, $module ) = splice( @_, 0, 2 );
         my @methods = ();
         if ( '-logger' eq $policy ) {
             cPanel::StateFile->import( '-logger' => $module );
         }
-        elsif( '-serializer' eq $policy ) {
-            _load_serializer_module( $module );
+        elsif ( '-serializer' eq $policy ) {
+            _load_serializer_module($module);
             $the_serializer = $module;
         }
         else {
@@ -61,32 +84,32 @@ sub _load_serializer_module {
     my ($module) = @_;
     die "Supplied serializer must be a module name.\n" if ref $module;
     die "'$module' does not look like a serializer" unless $module =~ m{^\w+(?:::\w+)*$};
-    eval "use $module;"; ## no critic (ProhibitStringyEval)
+    eval "use $module;";    ## no critic (ProhibitStringyEval)
     die $@ if $@;
     die 'Supplied serializer object does not support the correct interface.'
-        unless _valid_serializer( $module );
+      unless _valid_serializer($module);
     return;
 }
 
 sub _valid_serializer {
     my ($serializer) = @_;
-    foreach my $method ( qw/load save filename/ ) {
-        return unless eval { $serializer->can( $method ) };
+    foreach my $method (qw/load save filename/) {
+        return unless eval { $serializer->can($method) };
     }
     return 1;
 }
 
 sub _get_serializer {
     unless ( defined $the_serializer ) {
-        eval 'use cPanel::TQSerializer::Storable;';  ## no crititc (ProhibitStringyEval)
-        cPanel::StateFile->_throw( @_ ) if $@;
+        eval 'use cPanel::TQSerializer::Storable;';    ## no crititc (ProhibitStringyEval)
+        cPanel::StateFile->_throw(@_) if $@;
         $the_serializer = 'cPanel::TQSerializer::Storable';
     }
     return $the_serializer;
 }
 
 # Replacement for List::Util::first, so I don't need to bring in the whole module.
-sub _first (&@) {  ## no critic(ProhibitSubroutinePrototypes)
+sub _first (&@) {                                      ## no critic(ProhibitSubroutinePrototypes)
     my $pred = shift;
     local $_;
     foreach (@_) {
@@ -99,12 +122,13 @@ sub _first (&@) {  ## no critic(ProhibitSubroutinePrototypes)
 my $tasksched_uuid = 'TaskQueue-Scheduler';
 
 {
-    my $FILETYPE = 'TaskScheduler'; # Identifier at the beginning of the state file
-    my $CACHE_VERSION = 2; # Cache file version number.
+    my $FILETYPE      = 'TaskScheduler';    # Identifier at the beginning of the state file
+    my $CACHE_VERSION = 2;                  # Cache file version number.
 
     # Disk Cache & state file.
     #
     sub get_name { $_[0]->{scheduler_name}; }
+
     # --------------------------------------
     # Class methods
 
@@ -123,65 +147,71 @@ my $tasksched_uuid = 'TaskQueue-Scheduler';
         }
         $self->{serializer} ||= _get_serializer();
         if ( exists $args_ref->{token} ) {
-            my ($version,$name,$file) = split( ':\|:', $args_ref->{token} );
-            # have all parts
-            cPanel::StateFile->_throw( 'Invalid token.' )
-                unless defined $version and defined $name and defined $file;
-            # all parts make sense.
-            my $name_match = _get_serializer()->filename( "${name}_sched" );
-            cPanel::StateFile->_throw( 'Invalid token.' )
-                unless 'tqsched1' eq $version and $file =~ m{/\Q$name_match\E$};
+            my ( $version, $name, $file ) = split( ':\|:', $args_ref->{token} );
 
-            $self->{scheduler_name} = $name;
+            # have all parts
+            cPanel::StateFile->_throw('Invalid token.')
+              unless defined $version
+                  and defined $name
+                  and defined $file;
+
+            # all parts make sense.
+            my $name_match = _get_serializer()->filename("${name}_sched");
+            cPanel::StateFile->_throw('Invalid token.')
+              unless 'tqsched1' eq $version and $file =~ m{/\Q$name_match\E$};
+
+            $self->{scheduler_name}  = $name;
             $self->{disk_state_file} = $file;
         }
         else {
             $args_ref->{state_dir} ||= $args_ref->{cache_dir} if exists $args_ref->{cache_dir};
-            cPanel::StateFile->_throw( 'No caching directory supplied.' ) unless exists $args_ref->{state_dir};
-            cPanel::StateFile->_throw( 'No scheduler name supplied.' ) unless exists $args_ref->{name};
+            cPanel::StateFile->_throw('No caching directory supplied.') unless exists $args_ref->{state_dir};
+            cPanel::StateFile->_throw('No scheduler name supplied.')    unless exists $args_ref->{name};
 
-            $self->{disk_state_file} = $self->_serializer()->filename( "$args_ref->{state_dir}/$args_ref->{name}_sched" );
+            $self->{disk_state_file} = $self->_serializer()->filename("$args_ref->{state_dir}/$args_ref->{name}_sched");
             $self->{scheduler_name}  = $args_ref->{name};
         }
 
         # Make a disk file to track the object.
         my $state_args = {
-            state_file=>$self->{disk_state_file}, data_obj => $self,
+            state_file => $self->{disk_state_file}, data_obj => $self,
+
             # Deprecated version
-            exists $args_ref->{cache_timeout} ? (timeout => $args_ref->{cache_timeout}) : (),
-            exists $args_ref->{state_timeout} ? (timeout => $args_ref->{state_timeout}) : (),
-            exists $args_ref->{logger} ? (logger => $args_ref->{logger}) : (),
+            exists $args_ref->{cache_timeout} ? ( timeout => $args_ref->{cache_timeout} ) : (),
+            exists $args_ref->{state_timeout} ? ( timeout => $args_ref->{state_timeout} ) : (),
+            exists $args_ref->{logger}        ? ( logger  => $args_ref->{logger} )        : (),
         };
         eval {
-            $self->{disk_state} = cPanel::StateFile->new( $state_args );
+            $self->{disk_state} = cPanel::StateFile->new($state_args);
             1;
         } or do {
             my $ex = $@;
+
             # If not a loading error, rethrow.
-            cPanel::StateFile->_throw( $ex ) unless $ex =~ /Not a recognized|Invalid version/;
-            cPanel::StateFile->_warn( $ex );
-            cPanel::StateFile->_warn( "Moving bad state file and retry.\n" );
+            cPanel::StateFile->_throw($ex) unless $ex =~ /Not a recognized|Invalid version/;
+            cPanel::StateFile->_warn($ex);
+            cPanel::StateFile->_warn("Moving bad state file and retry.\n");
             cPanel::StateFile->_notify(
                 'Unable to load TaskQueue::Scheduler metadata',
-                "Loading of [$self->{disk_state_file}] failed: $ex\n"
-                . "Moving bad file to [$self->{disk_state_file}.broken] and retrying.\n"
+                "Loading of [$self->{disk_state_file}] failed: $ex\n" . "Moving bad file to [$self->{disk_state_file}.broken] and retrying.\n"
             );
             unlink "$self->{disk_state_file}.broken";
-            rename $self->{disk_state_file}, "$self->{disk_state_file}.broken"; 
+            rename $self->{disk_state_file}, "$self->{disk_state_file}.broken";
 
-            $self->{disk_state} = cPanel::StateFile->new( $state_args );
+            $self->{disk_state} = cPanel::StateFile->new($state_args);
         };
         return $self;
     }
 
     sub throw {
         my $self = shift;
-        return $self->{disk_state} ? $self->{disk_state}->throw( @_ ) : cPanel::StateFile->_throw( @_ );
+        return $self->{disk_state} ? $self->{disk_state}->throw(@_) : cPanel::StateFile->_throw(@_);
     }
+
     # Not using warn, so don't define it.
     sub info {
         my $self = shift;
-        return $self->{disk_state} ? $self->{disk_state}->info( @_ ) : undef;
+        return $self->{disk_state} ? $self->{disk_state}->info(@_) : undef;
     }
 
     # -------------------------------------------------------
@@ -199,26 +229,26 @@ my $tasksched_uuid = 'TaskQueue-Scheduler';
     # -------------------------------------------------------
     # Public methods
     sub load_from_cache {
-        my ($self, $fh) = @_;
+        my ( $self, $fh ) = @_;
 
         local $/;
-        my ($magic, $version, $meta) = $self->_serializer()->load( $fh );
+        my ( $magic, $version, $meta ) = $self->_serializer()->load($fh);
 
-        $self->throw( "Not a recognized TaskQueue Scheduler state file.\n" ) unless defined $magic and $magic eq $FILETYPE;
-        $self->throw( "Invalid version of TaskQueue Scheduler state file.\n" ) unless defined $version and $version eq $CACHE_VERSION;
+        $self->throw("Not a recognized TaskQueue Scheduler state file.\n")   unless defined $magic   and $magic   eq $FILETYPE;
+        $self->throw("Invalid version of TaskQueue Scheduler state file.\n") unless defined $version and $version eq $CACHE_VERSION;
 
         # Next id should continue increasing.
         #   (We might want to deal with wrap-around at some point.)
         $self->{next_id} = $meta->{nextid} if $meta->{nextid} > $self->{next_id};
+
         # Clean queues that have been read from disk.
-        $self->{time_queue} = [ grep { _is_item_sane( $_ ) } @{$meta->{waiting_queue}} ];
+        $self->{time_queue} = [ grep { _is_item_sane($_) } @{ $meta->{waiting_queue} } ];
 
         return 1;
     }
 
-
     sub save_to_cache {
-        my ($self,$fh) = @_;
+        my ( $self, $fh ) = @_;
 
         my $meta = {
             nextid        => $self->{next_id},
@@ -228,25 +258,25 @@ my $tasksched_uuid = 'TaskQueue-Scheduler';
     }
 
     sub schedule_task {
-        my ($self, $command, $args) = @_;
+        my ( $self, $command, $args ) = @_;
 
-        $self->throw( 'Cannot queue an empty command.' ) unless defined $command;
-        $self->throw( 'Args is not a hash ref.' ) unless defined $args and 'HASH' eq ref $args;
+        $self->throw('Cannot queue an empty command.') unless defined $command;
+        $self->throw('Args is not a hash ref.') unless defined $args and 'HASH' eq ref $args;
 
         my $time = time;
         $time += $args->{delay_seconds} if exists $args->{delay_seconds};
         $time = $args->{at_time} if exists $args->{at_time};
 
-        if ( eval { $command->isa( 'cPanel::TaskQueue::Task' ) } ) {
+        if ( eval { $command->isa('cPanel::TaskQueue::Task') } ) {
             if ( 0 == $command->retries_remaining() ) {
-                $self->info( 'Task with 0 retries not scheduled.' );
+                $self->info('Task with 0 retries not scheduled.');
                 return;
             }
             return $self->_schedule_the_task( $time, $command );
         }
 
         # must have non-space characters to be a command.
-        $self->throw( 'Cannot queue an empty command.' ) unless $command =~ /\S/;
+        $self->throw('Cannot queue an empty command.') unless $command =~ /\S/;
 
         my @retry_attrs = ();
         if ( exists $args->{attempts} ) {
@@ -257,8 +287,10 @@ my $tasksched_uuid = 'TaskQueue-Scheduler';
             );
         }
         my $task = cPanel::TaskQueue::Task->new(
-            { cmd=>$command, nsid=>$tasksched_uuid, id=>$self->{next_id}++,
-              @retry_attrs }
+            {
+                cmd => $command, nsid => $tasksched_uuid, id => $self->{next_id}++,
+                @retry_attrs
+            }
         );
         return $self->_schedule_the_task( $time, $task );
     }
@@ -266,44 +298,45 @@ my $tasksched_uuid = 'TaskQueue-Scheduler';
     sub unschedule_task {
         my ( $self, $uuid ) = @_;
 
-        unless ( _is_valid_uuid( $uuid ) ) {
-            $self->throw( 'No Task uuid argument passed to unschedule_task.' );
+        unless ( _is_valid_uuid($uuid) ) {
+            $self->throw('No Task uuid argument passed to unschedule_task.');
         }
 
         # Lock the queue before we begin accessing it.
-        my $guard = $self->{disk_state}->synch();
-        my $old_count = @{$self->{time_queue}};
+        my $guard     = $self->{disk_state}->synch();
+        my $old_count = @{ $self->{time_queue} };
+
+        $self->{time_queue} = [ grep { $_->{task}->uuid() ne $uuid } @{ $self->{time_queue} } ];
 
-        $self->{time_queue} = [ grep { $_->{task}->uuid() ne $uuid } @{$self->{time_queue}} ];
         # All changes complete, save to disk.
         $guard->update_file();
-        return $old_count > @{$self->{time_queue}};
+        return $old_count > @{ $self->{time_queue} };
     }
 
     sub is_task_scheduled {
         my ( $self, $uuid ) = @_;
 
-        unless ( _is_valid_uuid( $uuid ) ) {
-            $self->throw( 'No Task uuid argument passed to is_task_scheduled.' );
+        unless ( _is_valid_uuid($uuid) ) {
+            $self->throw('No Task uuid argument passed to is_task_scheduled.');
         }
 
         # Update from disk, but don't worry about lock. Information only.
         $self->{disk_state}->synch();
 
-        return _first { $_->{task}->uuid() eq $uuid } @{$self->{time_queue}};
+        return _first { $_->{task}->uuid() eq $uuid } @{ $self->{time_queue} };
     }
 
     sub when_is_task_scheduled {
         my ( $self, $uuid ) = @_;
 
         unless ( _is_valid_uuid($uuid) ) {
-            $self->throw( 'No Task uuid argument passed to when_is_task_scheduled.' );
+            $self->throw('No Task uuid argument passed to when_is_task_scheduled.');
         }
 
         # Update from disk, but don't worry about lock. Information only.
         $self->{disk_state}->synch();
 
-        my $task = _first { $_->{task}->uuid() eq $uuid } @{$self->{time_queue}};
+        my $task = _first { $_->{task}->uuid() eq $uuid } @{ $self->{time_queue} };
         return unless defined $task;
         return $task->{time};
     }
@@ -313,7 +346,7 @@ my $tasksched_uuid = 'TaskQueue-Scheduler';
 
         # Update from disk, but don't worry about lock. Information only.
         $self->{disk_state}->synch();
-        return scalar @{$self->{time_queue}};
+        return scalar @{ $self->{time_queue} };
     }
 
     sub peek_next_task {
@@ -321,7 +354,7 @@ my $tasksched_uuid = 'TaskQueue-Scheduler';
 
         # Update from disk, but don't worry about lock. Information only.
         $self->{disk_state}->synch();
-        return unless @{$self->{time_queue}};
+        return unless @{ $self->{time_queue} };
 
         return $self->{time_queue}->[0]->{task}->clone();
     }
@@ -331,16 +364,16 @@ my $tasksched_uuid = 'TaskQueue-Scheduler';
 
         # Update from disk, but don't worry about lock. Information only.
         $self->{disk_state}->synch();
-        return unless @{$self->{time_queue}};
+        return unless @{ $self->{time_queue} };
 
         return $self->{time_queue}->[0]->{time} - time;
     }
 
     sub process_ready_tasks {
-        my ($self, $queue) = @_;
+        my ( $self, $queue ) = @_;
 
-        unless ( defined $queue and eval { $queue->can( 'queue_task' ) } ) {
-            $self->throw( 'No valid queue supplied.' );
+        unless ( defined $queue and eval { $queue->can('queue_task') } ) {
+            $self->throw('No valid queue supplied.');
         }
 
         # Don't generate lock yet, we may not need one.
@@ -348,22 +381,24 @@ my $tasksched_uuid = 'TaskQueue-Scheduler';
         my $count = 0;
         my $guard;
         eval {
-            while ( @{$self->{time_queue}} ) {
+            while ( @{ $self->{time_queue} } ) {
                 my $item = $self->{time_queue}->[0];
 
                 last if time < $item->{time};
                 if ( !$guard ) {
+
                     # Now we know we'll be changing the schedule, so we need to
                     # lock it.
                     $guard ||= $self->{disk_state}->synch();
                     next;
                 }
+
                 # Should be safe from deadlock unless queue calls back to me.
                 $queue->queue_task( $item->{task} );
                 ++$count;
 
                 # Only remove from the schedule when the queue has processed it.
-                shift @{$self->{time_queue}};
+                shift @{ $self->{time_queue} };
             }
         };
         my $ex = $@;
@@ -384,7 +419,11 @@ my $tasksched_uuid = 'TaskQueue-Scheduler';
 
         $self->{disk_state}->synch();
 
-        return [ map { {time=>$_->{time}, task=>$_->{task}->clone()} } @{$self->{time_queue}} ];
+        return [
+            map {
+                { time => $_->{time}, task => $_->{task}->clone() }
+              } @{ $self->{time_queue} }
+        ];
     }
 
     # ---------------------------------------------------------------
@@ -394,19 +433,22 @@ my $tasksched_uuid = 'TaskQueue-Scheduler';
 
         my $guard = $self->{disk_state}->synch();
         my $item = { time => $time, task => $task };
+
         # if the list is empty, or time after all in list.
-        if ( !@{$self->{time_queue}} or $time >= $self->{time_queue}->[-1]->{time} ) {
-            push @{$self->{time_queue}}, $item;
+        if ( !@{ $self->{time_queue} } or $time >= $self->{time_queue}->[-1]->{time} ) {
+            push @{ $self->{time_queue} }, $item;
         }
         elsif ( $time < $self->{time_queue}->[0]->{time} ) {
+
             # schedule before anything in the list
-            unshift @{$self->{time_queue}}, $item;
+            unshift @{ $self->{time_queue} }, $item;
         }
         else {
+
             # find the correct spot in the list.
-            foreach my $i ( 1 .. $#{$self->{time_queue}} ) {
+            foreach my $i ( 1 .. $#{ $self->{time_queue} } ) {
                 next unless $self->{time_queue}->[$i]->{time} > $time;
-                splice( @{$self->{time_queue}}, $i, 0, $item );
+                splice( @{ $self->{time_queue} }, $i, 0, $item );
                 last;
             }
         }
@@ -419,12 +461,12 @@ my $tasksched_uuid = 'TaskQueue-Scheduler';
         my ($item) = @_;
         return unless 'HASH' eq ref $item;
         return unless exists $item->{task} and exists $item->{time};
-        return unless eval { $item->{task}->isa( 'cPanel::TaskQueue::Task' ) };
+        return unless eval { $item->{task}->isa('cPanel::TaskQueue::Task') };
         return $item->{time} =~ /^\d+$/;
     }
 
     sub _is_valid_uuid {
-        return cPanel::TaskQueue::Task::is_valid_taskid( shift );
+        return cPanel::TaskQueue::Task::is_valid_taskid(shift);
     }
 }
 
